/**
 * Copyright (c) 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.mo.components.bc.soap;

import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringSubFunction;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.AbstractThreadPool;
import org.ow2.petals.jmx.api.api.JMXClient;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.PetalsBcSoapMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.exception.MonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.exception.MonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;

/**
 * The monitoring sub-function about HTTP thread pool of the Petals BC SOAP.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class HttpThreadPool extends AbstractThreadPool implements MonitoringSubFunction {

    private final static String SUBFCT_NAME = "http-thread-pool";

    private final static String SUBFCT_DESCRIPTION = "HTTP Thread pool statistics";

    @Override
    public String getName() {
        return SUBFCT_NAME;
    }

    @Override
    public String getDescription() {
        return SUBFCT_DESCRIPTION;
    }

    @Override
    protected ThreadPoolMetrics getThreadPoolMetrics(final JMXClient client,
            final String componentIdentifier)
            throws MonitoringServiceDoesNotExistException, MonitoringServiceErrorException, ConnectionErrorException {

        final PetalsBcSoapMonitoringServiceClient bcSoapClient = client
                .getPetalsBcSoapMonitoringServiceClient(componentIdentifier);
        return bcSoapClient.getHttpServerThreadPoolMetrics();
    }

}
