/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */

package org.ow2.petals.cli.extension.command.monitoring.mo.components.framework;

import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringSubFunction;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.AbstractThreadPool;
import org.ow2.petals.jmx.api.api.JMXClient;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;

/**
 * The monitoring sub-function about the message exchange processor thread pool
 * of a component.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class MexProcessorThreadPool extends AbstractThreadPool implements MonitoringSubFunction {

    private final static String SUBFCT_NAME = "mex-processor-thread-pool";

    private final static String SUBFCT_DESCRIPTION = "Message exchange processor thread pool statistics";

    @Override
    public String getName() {
        return SUBFCT_NAME;
    }

    @Override
    public String getDescription() {
        return SUBFCT_DESCRIPTION;
    }

    @Override
    protected ThreadPoolMetrics getThreadPoolMetrics(final JMXClient client,
            final String componentIdentifier)
            throws ComponentMonitoringServiceDoesNotExistException,
            ComponentMonitoringServiceErrorException, ConnectionErrorException {

        final ComponentMonitoringServiceClient cdkBasedClient = client
                .getComponentMonitoringServiceClient(componentIdentifier);
        return cdkBasedClient.getMexProcessorThreadPoolMetrics();
    }

}
