/**
 * Copyright (c) 2016-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.mo.container.transporter.remote;

import java.util.Map;

import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringSubFunction;
import org.ow2.petals.jmx.api.api.JMXClient;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.exception.TcpTransporterMonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.remote.exception.TcpTransporterMonitoringServiceErrorException;

/**
 * The monitoring sub-function about delivered messages by the TCP transporter of the Petals container
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DeliveredOutgoingMessages extends AbstractDeliveredMessages implements MonitoringSubFunction {

    private final static String SUBFCT_NAME = "delivered-outgoing-messages";

    private final static String SUBFCT_DESCRIPTION = "Delivered outgoing messages";

    @Override
    public String getName() {
        return SUBFCT_NAME;
    }

    @Override
    public String getDescription() {
        return SUBFCT_DESCRIPTION;
    }

    @Override
    protected Map<String[], Long> getMetrics(JMXClient client) throws TcpTransporterMonitoringServiceErrorException,
            TcpTransporterMonitoringServiceDoesNotExistException, ConnectionErrorException {
        return client.getTcpTransporterMonitoringServiceClient().getDeliveredOutgoingMessagesCount();
    }
}
