/**
 * Copyright (c) 2016-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.mo;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.junit.Test;
import org.ow2.petals.cli.api.shell.Shell;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringObject;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringObjectRegistration;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringObjectRegistror;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.DuplicatedMonitoringObjectException;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.DuplicatedMonitoringSubFunctionException;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.InvalidMonitoringObjectNameException;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.InvalidMonitoringSubFunctionNameException;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.bc.soap.BcSoap;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.framework.CdkBasedComponent;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.se.flowable.SeFlowable;
import org.ow2.petals.cli.extension.command.monitoring.mo.container.transporter.local.LocalTransporter;
import org.ow2.petals.cli.extension.command.monitoring.mo.container.transporter.remote.TcpTransporter;

/**
 * A unit test to check that Monitoring extension of Petals ESB CLI embeds all its monitoring objects, and only the
 * expected ones.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class EmbeddedMonitoringObjectsTest {

    private class MyMonitoringObjectRegistror implements MonitoringObjectRegistror {
        
        final private Map<String, MonitoringObject> monitoringObjects = new HashMap<>();
        
        @Override
        public void registersMonitoringObjects(final MonitoringObject monitoringObject)
                throws DuplicatedMonitoringObjectException, DuplicatedMonitoringSubFunctionException,
                InvalidMonitoringObjectNameException, InvalidMonitoringSubFunctionNameException, IllegalArgumentException {
            this.monitoringObjects.put(monitoringObject.getName(), monitoringObject);
        }
        
        @Override
        public Shell getShell() {
            return null;
        }
        
        @Override
        public Map<String, MonitoringObject> getMonitoringObjects() {
            return this.monitoringObjects;
        }
    }

    private final static List<Class<? extends MonitoringObject>> EXPECTED_MONITORING_OBJECTS;

    static {
        EXPECTED_MONITORING_OBJECTS = new ArrayList<>();
        EXPECTED_MONITORING_OBJECTS.add(CdkBasedComponent.class);
        EXPECTED_MONITORING_OBJECTS.add(BcSoap.class);
        EXPECTED_MONITORING_OBJECTS.add(SeFlowable.class);
        EXPECTED_MONITORING_OBJECTS.add(LocalTransporter.class);
        EXPECTED_MONITORING_OBJECTS.add(TcpTransporter.class);
    }

    @Test
    public void expectedMonitoringObjects() {
        
        final MonitoringObjectRegistror registror = new MyMonitoringObjectRegistror();
        MonitoringObjectRegistration.registers(registror);

        final List<Class<? extends MonitoringObject>> expectedMonitoringObjects = new ArrayList<>(
                EXPECTED_MONITORING_OBJECTS);

        final Map<String, MonitoringObject> monitoringObjects = registror.getMonitoringObjects();
        final Iterator<MonitoringObject> itMonitoringObjects = monitoringObjects.values().iterator();
        while (itMonitoringObjects.hasNext()) {
            final MonitoringObject monitoringObject = itMonitoringObjects.next();

            final Iterator<Class<? extends MonitoringObject>> itExpectedMonitoringObjects = expectedMonitoringObjects.iterator();
            while (itExpectedMonitoringObjects.hasNext()) {
                final Class<? extends MonitoringObject> expectedMonitoringObject = itExpectedMonitoringObjects.next();
                if (expectedMonitoringObject.isInstance(monitoringObject)) {
                    itExpectedMonitoringObjects.remove();
                    itMonitoringObjects.remove();
                    break;
                }
            }
        }

        assertEquals("Few monitoring objects are not expected", 0, monitoringObjects.size());
        assertEquals("Few monitoring objects are missing", 0, expectedMonitoringObjects.size());
    }

}
